@@ -118,15 +118,13 @@ def last_letter(word):
     return return_data
 
 
-def soften(parameter_word, proper_noun=False, negative=False):
+def soften(parameter_word):
     word = parameter_word
 
     actual_last_letter = last_letter(word)
     actual_last_vowel = last_vowel(word)
 
-    if proper_noun:
-        word += '\''
-    elif 'discontinuous_hard_consonant' in actual_last_letter:
+    if 'discontinuous_hard_consonant' in actual_last_letter:
         if actual_last_vowel['vowel_count'] > 1:
             if word not in consonants.ARABIC_K or actual_last_letter.get('letter') != 'k':
                 if word in consonants.ARABIC_T or actual_last_letter.get('letter') != 't':
